==> effing_0.3.2-1.tar.gz: effing-0.3.2/fbactions.h <==
/* This file is part of effing
 *
 * Copyright (C) 2010 Richard Merren <richard@merren.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef FBACTIONS_H
#define FBACTIONS_H

#include <QObject>
#include <QDateTime>
#include <QMultiMap>
#include <QtNetwork/QNetworkReply>
#include "settingsmanager.h"

class FbActions : public QObject
{
    Q_OBJECT
public:
    explicit FbActions(QObject *parent = 0);
    bool is_need_auth_token();
    void set_token(QString token);

signals:
    void status_available(QString status, QDateTime timestamp);
    void status_successfully_set();

public slots:
    void request_status();
    void unauthorize();
    void set_status(QString status);

private:
    QString get_auth_token();
    QNetworkAccessManager access_manager;
    SettingsManager settings_manager;

private slots:
    void handle_http_response(QNetworkReply* reply);
};

#endif // FBACTIONS_H

==> effing_0.5.0-1.tar.gz: effing-0.5.0/fbactions.h <==
/* This file is part of effing
 *
 * Copyright (C) 2010 Richard Merren <richard@merren.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef FBACTIONS_H
#define FBACTIONS_H

#include <QObject>
#include <QDateTime>
#include <QMultiMap>
#include <QtNetwork/QNetworkReply>
#include <QtScript/QScriptValue>
#include "settingsmanager.h"
#include "messagedto.h"

class FbActions : public QObject
{
    Q_OBJECT
public:
    explicit FbActions(QObject *parent = 0);
    bool is_need_auth_token();
    void set_token(QString token);

signals:
    void status_available(QString status);
    void status_successfully_set();

public slots:
    void request_status();
    void unauthorize();
    void set_status(QString status);

private:
    QString get_auth_token();
    QNetworkAccessManager access_manager;
    SettingsManager settings_manager;
    void emit_simple_message(QString text);
    QDateTime parseTime(QScriptValue jsonNode);

private slots:
    void handle_http_response(QNetworkReply* reply);
};

#endif // FBACTIONS_H
